@@ -1,6 +1,6 @@
 #!/bin/bash
 
-(cd tests; sh ./tests_quick.sh /usr/bin/elk-lapw)
+(cd tests; bash ./tests_quick.sh /usr/bin/elk-lapw)
 for i in tests/test-*/test.log; do	\
   if [ -e $$i ]; then			\
     echo "Error for test $$i:";		\
